AppInfoFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • AppInfoFlutterPlatform
Implementers

Constructors

AppInfoFlutterPlatform()
Constructs a AppInfoFlutterPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAppName() Future<String?>
getBuildNumber() Future<String?>
getPackageName() Future<String?>
getVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AppInfoFlutterPlatform
The default instance of AppInfoFlutterPlatform to use.
getter/setter pair